==> spip_4.1.5+dfsg.orig.tar.xz: ecrire/lang/public_ca.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/public?lang_cible=ca
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'accueil_site' => 'Inici',
	'article' => 'Article',
	'articles' => 'Articles',
	'articles_auteur' => 'Articles d’aquest autor',
	'articles_populaires' => 'Els articles més populars',
	'articles_rubrique' => 'Articles d’aquesta secció',
	'aucun_article' => 'No hi ha cap article en aquesta adreça',
	'aucun_auteur' => 'No hi ha cap autor/a a aquesta adreça',
	'aucun_site' => 'No hi ha cap lloc web en aquesta adreça',
	'aucune_breve' => 'No hi ha cap breu a aquesta adreça',
	'aucune_rubrique' => 'No hi ha cap secció a aquesta adreça',
	'auteur' => 'Autor',
	'autres' => 'Altres',
	'autres_breves' => 'Altres breus',
	'autres_groupes_mots_clefs' => 'Altres grups de paraules clau',
	'autres_sites' => 'Altres llocs webs',

	// B
	'bonjour' => 'Bon dia',

	// C
	'commenter_site' => 'Comentar aquest lloc web',
	'contact' => 'Contacte',
	'copie_document_impossible' => 'Impossible copiar el document',

	// D
	'date' => ' Data',
	'dernier_ajout' => 'Darrer afegit',
	'dernieres_breves' => 'Darreres breus',
	'derniers_articles' => 'Darrers articles',
	'derniers_commentaires' => 'Darrers comentaris',
	'derniers_messages_forum' => 'Darrers missatges publicats als fòrums',

	// E
	'edition_mode_texte' => 'Edició en mode text de ',
	'en_reponse' => 'En resposta a:',
	'en_resume' => 'En resum',
	'envoyer_message' => 'Enviar un missatge',
	'espace_prive' => 'Espai privat',

	// F
	'formats_acceptes' => 'Formats acceptats: @formats@.',

	// H
	'hierarchie_site' => 'Jerarquia del lloc',

	// J
	'jours' => 'dies',

	// L
	'lien_connecter' => 'Connectar-se',

	// M
	'meme_auteur' => 'Del mateix/a autor/a',
	'meme_rubrique' => 'A la mateixa secció',
	'memes_auteurs' => 'Dels mateixos autors',
	'message' => 'Missatge',
	'messages_forum' => 'Missatges',
	'messages_recents' => 'Els missatges més recents als fòrums',
	'mots_clef' => 'Paraula clau',
	'mots_clefs' => 'Paraules clau',
	'mots_clefs_meme_groupe' => 'Paraules clau al mateix grup',

	// N
	'navigation' => 'Navegació',
	'nom' => 'Nom',
	'nouveautes' => 'Les novetats',
	'nouveautes_web' => 'Novetats a la Web',
	'nouveaux_articles' => 'Articles nous',
	'nouvelles_breves' => 'Noves breus',

	// P
	'page_precedente' => 'pàgina anterior',
	'page_suivante' => 'pàgina següent',
	'par_auteur' => 'per ',
	'participer_site' => 'Podeu participar en la vida d’aquest lloc web i proposar els vostres articles si ompliu la inscripció que hi ha a continuació. Immediatament rebreu un correu electrònic indicant-vos els codis d’accés a l’espai privat de la web.',
	'plan_site' => 'Mapa del lloc Web',
	'popularite' => 'Popularitat',
	'poster_message' => 'Escriure un missatge',
	'proposer_site' => 'Pots proposar un lloc web per afegir-lo a aquesta secció:',

	// R
	'repondre_article' => 'Respondre a aquest article',
	'repondre_breve' => 'Respondre a aquesta breu',
	'resultats_recherche' => 'Resultats de la recerca',
	'retour_debut_forums' => 'Retorn al començament dels fòrums',
	'rubrique' => 'Secció',
	'rubriques' => 'Seccions',

	// S
	'signatures_petition' => 'Signatures',
	'site_realise_avec_spip' => 'Lloc Web fet amb l’SPIP',
	'sites_web' => 'Llocs Web',
	'sous_rubriques' => 'Subseccions',
	'spam' => 'Spam',
	'suite' => 'Segueix',
	'sur_web' => 'Sobre la Web',
	'syndiquer_rubrique' => 'Sindicar aquesta secció',
	'syndiquer_site' => 'Sindicar tot el lloc Web',

	// T
	'texte_lettre_information' => 'Veure la carta de presentació del lloc Web',
	'texte_lettre_information_2' => 'Aquesta carta recull les novetats publicades des de',

	// V
	'ver_imprimer' => 'Versió per imprimir',
	'voir_en_ligne' => 'Veure en línia',
	'voir_squelette' => 'descarregar l’esquelet d’aquesta pàgina'
);

==> spip_4.4.8+dfsg.orig.tar.xz: ecrire/lang/public_ca.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/public?lang_cible=ca
// ** ne pas modifier le fichier **

return [

	// A
	'accueil_site' => 'Inici',
	'article' => 'Article',
	'articles' => 'Articles',
	'articles_auteur' => 'Articles d’aquest autor',
	'articles_populaires' => 'Els articles més populars',
	'articles_rubrique' => 'Articles d’aquesta secció',
	'aucun_article' => 'No hi ha cap article en aquesta adreça',
	'aucun_auteur' => 'No hi ha cap autor/a a aquesta adreça',
	'aucun_site' => 'No hi ha cap lloc web en aquesta adreça',
	'aucune_breve' => 'No hi ha cap breu a aquesta adreça',
	'aucune_rubrique' => 'No hi ha cap secció a aquesta adreça',
	'auteur' => 'Autor',
	'autres' => 'Altres',
	'autres_breves' => 'Altres breus',
	'autres_groupes_mots_clefs' => 'Altres grups de paraules clau',
	'autres_sites' => 'Altres llocs webs',

	// B
	'bonjour' => 'Bon dia',

	// C
	'commenter_site' => 'Comentar aquest lloc web',
	'contact' => 'Contacte',
	'copie_document_impossible' => 'Impossible copiar el document',

	// D
	'date' => ' Data',
	'dernier_ajout' => 'Darrer afegit',
	'dernieres_breves' => 'Darreres breus',
	'derniers_articles' => 'Darrers articles',
	'derniers_commentaires' => 'Darrers comentaris',
	'derniers_messages_forum' => 'Darrers missatges publicats als fòrums',

	// E
	'edition_mode_texte' => 'Edició en mode text de ',
	'en_reponse' => 'En resposta a:',
	'en_resume' => 'En resum',
	'envoyer_message' => 'Enviar un missatge',
	'espace_prive' => 'Espai privat',

	// F
	'formats_acceptes' => 'Formats acceptats: @formats@.',

	// H
	'hierarchie_site' => 'Jerarquia del lloc',

	// J
	'jours' => 'dies',

	// L
	'lien_connecter' => 'Connectar-se',

	// M
	'meme_auteur' => 'Del mateix/a autor/a',
	'meme_rubrique' => 'A la mateixa secció',
	'memes_auteurs' => 'Dels mateixos autors',
	'message' => 'Missatge',
	'messages_forum' => 'Missatges',
	'messages_recents' => 'Els missatges més recents als fòrums',
	'mots_clef' => 'Paraula clau',
	'mots_clefs' => 'Paraules clau',
	'mots_clefs_meme_groupe' => 'Paraules clau al mateix grup',

	// N
	'navigation' => 'Navegació',
	'nom' => 'Nom',
	'nouveautes' => 'Les novetats',
	'nouveautes_web' => 'Novetats a la Web',
	'nouveaux_articles' => 'Articles nous',
	'nouvelles_breves' => 'Noves breus',

	// P
	'page_precedente' => 'pàgina anterior',
	'page_suivante' => 'pàgina següent',
	'par_auteur' => 'per ',
	'participer_site' => 'Podeu participar en la vida d’aquest lloc web i proposar els vostres articles si ompliu la inscripció que hi ha a continuació. Immediatament rebreu un correu electrònic indicant-vos els codis d’accés a l’espai privat de la web.',
	'plan_site' => 'Mapa del lloc Web',
	'popularite' => 'Popularitat',
	'poster_message' => 'Escriure un missatge',
	'proposer_site' => 'Pots proposar un lloc web per afegir-lo a aquesta secció:',

	// R
	'repondre_article' => 'Respondre a aquest article',
	'repondre_breve' => 'Respondre a aquesta breu',
	'resultats_recherche' => 'Resultats de la recerca',
	'retour_debut_forums' => 'Retorn al començament dels fòrums',
	'rubrique' => 'Secció',
	'rubriques' => 'Seccions',

	// S
	'signatures_petition' => 'Signatures',
	'site_realise_avec_spip' => 'Lloc Web fet amb l’SPIP',
	'sites_web' => 'Llocs Web',
	'sous_rubriques' => 'Subseccions',
	'spam' => 'Spam',
	'suite' => 'Segueix',
	'sur_web' => 'Sobre la Web',
	'syndiquer_rubrique' => 'Sindicar aquesta secció',
	'syndiquer_site' => 'Sindicar tot el lloc Web',

	// T
	'texte_lettre_information' => 'Veure la carta de presentació del lloc Web',
	'texte_lettre_information_2' => 'Aquesta carta recull les novetats publicades des de',

	// V
	'ver_imprimer' => 'Versió per imprimir',
	'voir_en_ligne' => 'Veure en línia',
	'voir_squelette' => 'descarregar l’esquelet d’aquesta pàgina',
];
